/****************************************************************************
** Meta object code from reading C++ file 'PropertiesTypes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../union-6.7.3/src/PropertiesTypes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PropertiesTypes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Union10PropertiesE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Properties::qt_create_metaobjectdata<qt_meta_tag_ZN5Union10PropertiesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Properties",
        "ImageFlag",
        "RepeatX",
        "RepeatY",
        "RepeatBoth",
        "StretchX",
        "StretchY",
        "StretchBoth",
        "Mask",
        "InvertedMask",
        "LineStyle",
        "None",
        "Solid",
        "AlignmentContainer",
        "Item",
        "Content",
        "Background",
        "Alignment",
        "Unspecified",
        "Start",
        "Center",
        "End",
        "Fill",
        "StackCenter",
        "StackFill",
        "TextWrapMode",
        "NoWrap",
        "WordWrap",
        "ManualWrap",
        "WrapAnywhere",
        "WrapAtWordBoundaryOrAnywhere",
        "TextElide",
        "Left",
        "Middle",
        "Right"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ImageFlag'
        QtMocHelpers::EnumData<ImageFlag>(1, 1, QMC::EnumIsScoped).add({
            {    2, ImageFlag::RepeatX },
            {    3, ImageFlag::RepeatY },
            {    4, ImageFlag::RepeatBoth },
            {    5, ImageFlag::StretchX },
            {    6, ImageFlag::StretchY },
            {    7, ImageFlag::StretchBoth },
            {    8, ImageFlag::Mask },
            {    9, ImageFlag::InvertedMask },
        }),
        // enum 'LineStyle'
        QtMocHelpers::EnumData<LineStyle>(10, 10, QMC::EnumIsScoped).add({
            {   11, LineStyle::None },
            {   12, LineStyle::Solid },
        }),
        // enum 'AlignmentContainer'
        QtMocHelpers::EnumData<AlignmentContainer>(13, 13, QMC::EnumIsScoped).add({
            {   14, AlignmentContainer::Item },
            {   15, AlignmentContainer::Content },
            {   16, AlignmentContainer::Background },
        }),
        // enum 'Alignment'
        QtMocHelpers::EnumData<Alignment>(17, 17, QMC::EnumIsScoped).add({
            {   18, Alignment::Unspecified },
            {   19, Alignment::Start },
            {   20, Alignment::Center },
            {   21, Alignment::End },
            {   22, Alignment::Fill },
            {   23, Alignment::StackCenter },
            {   24, Alignment::StackFill },
        }),
        // enum 'TextWrapMode'
        QtMocHelpers::EnumData<TextWrapMode>(25, 25, QMC::EnumIsScoped).add({
            {   26, TextWrapMode::NoWrap },
            {   27, TextWrapMode::WordWrap },
            {   28, TextWrapMode::ManualWrap },
            {   29, TextWrapMode::WrapAnywhere },
            {   30, TextWrapMode::WrapAtWordBoundaryOrAnywhere },
        }),
        // enum 'TextElide'
        QtMocHelpers::EnumData<TextElide>(31, 31, QMC::EnumIsScoped).add({
            {   11, TextElide::None },
            {   32, TextElide::Left },
            {   33, TextElide::Middle },
            {   34, TextElide::Right },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN5Union10PropertiesE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN5Union10PropertiesE =
    Union::Properties::qt_create_metaobjectdata<qt_meta_tag_ZN5Union10PropertiesE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN5Union10PropertiesE =
    qt_staticMetaObjectContent_ZN5Union10PropertiesE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN5Union10PropertiesE =
    qt_staticMetaObjectContent_ZN5Union10PropertiesE.relocatingData;

Q_CONSTINIT const QMetaObject Union::Properties::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN5Union10PropertiesE.stringdata,
    qt_staticMetaObjectStaticContent_ZN5Union10PropertiesE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN5Union10PropertiesE.metaTypes,
    nullptr
} };

QT_WARNING_POP
