/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<AlignmentPropertyGroup.h>)
#  include <AlignmentPropertyGroup.h>
#endif
#if __has_include(<BackgroundPropertyGroup.h>)
#  include <BackgroundPropertyGroup.h>
#endif
#if __has_include(<BorderPropertyGroup.h>)
#  include <BorderPropertyGroup.h>
#endif
#if __has_include(<CornerPropertyGroup.h>)
#  include <CornerPropertyGroup.h>
#endif
#if __has_include(<CornersPropertyGroup.h>)
#  include <CornersPropertyGroup.h>
#endif
#if __has_include(<Icon.h>)
#  include <Icon.h>
#endif
#if __has_include(<IconPropertyGroup.h>)
#  include <IconPropertyGroup.h>
#endif
#if __has_include(<ImagePropertyGroup.h>)
#  include <ImagePropertyGroup.h>
#endif
#if __has_include(<LayoutPropertyGroup.h>)
#  include <LayoutPropertyGroup.h>
#endif
#if __has_include(<LinePropertyGroup.h>)
#  include <LinePropertyGroup.h>
#endif
#if __has_include(<Mnemonics.h>)
#  include <Mnemonics.h>
#endif
#if __has_include(<OffsetPropertyGroup.h>)
#  include <OffsetPropertyGroup.h>
#endif
#if __has_include(<OutlinePropertyGroup.h>)
#  include <OutlinePropertyGroup.h>
#endif
#if __has_include(<Positioner.h>)
#  include <Positioner.h>
#endif
#if __has_include(<QuickElement.h>)
#  include <QuickElement.h>
#endif
#if __has_include(<QuickStyle.h>)
#  include <QuickStyle.h>
#endif
#if __has_include(<ShadowPropertyGroup.h>)
#  include <ShadowPropertyGroup.h>
#endif
#if __has_include(<SizePropertyGroup.h>)
#  include <SizePropertyGroup.h>
#endif
#if __has_include(<StyleHints.h>)
#  include <StyleHints.h>
#endif
#if __has_include(<StylePropertyGroup.h>)
#  include <StylePropertyGroup.h>
#endif
#if __has_include(<StyledRectangle.h>)
#  include <StyledRectangle.h>
#endif
#if __has_include(<TextPropertyGroup.h>)
#  include <TextPropertyGroup.h>
#endif
#if __has_include(<Types.h>)
#  include <Types.h>
#endif
#if __has_include(<WheelHandler.h>)
#  include <WheelHandler.h>
#endif
#if __has_include(<WindowHandler.h>)
#  include <WindowHandler.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_union_impl()
{
    qmlRegisterModule("org.kde.union.impl", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QQuickAttachedPropertyPropagator *>().id();
    qmlRegisterTypesAndRevisions<Union::Mnemonics>("org.kde.union.impl", 254);
    qmlRegisterEnum<Union::Mnemonics::ControlType>("Union::Mnemonics::ControlType");
    qmlRegisterTypesAndRevisions<Union::Quick::Alignment>("org.kde.union.impl", 254);
    qmlRegisterEnum<Union::Quick::Alignment::AlignmentType>("Union::Quick::Alignment::AlignmentType");
    qmlRegisterTypesAndRevisions<Union::Quick::AlignmentPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::BackgroundPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::BorderPropertyGroup>("org.kde.union.impl", 254);
    QMetaType::fromType<Union::Element *>().id();
    qmlRegisterNamespaceAndRevisions(&Union::Element::staticMetaObject, "org.kde.union.impl", 254, nullptr, &Union::Quick::ColorSet::staticMetaObject, nullptr);
    qmlRegisterEnum<Union::Element::States>("Union::Element::States");
    qmlRegisterEnum<Union::Element::State>("Union::Element::State");
    qmlRegisterEnum<Union::Element::ColorSet>("Union::Element::ColorSet");
    qmlRegisterEnum<Union::Element::Changes>("Union::Element::Changes");
    qmlRegisterEnum<Union::Element::Change>("Union::Element::Change");
    qmlRegisterTypesAndRevisions<Union::Quick::CornerPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::CornersPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::ElementAttribute>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::ElementHint>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::Icon>("org.kde.union.impl", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::IconPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::ImagePropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::LayoutPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::LinePropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::OffsetPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::OutlinePropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::PositionedItem>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::Positioner>("org.kde.union.impl", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &Union::Quick::PositionerSource::staticMetaObject;},
            "Union::Quick::PositionerSource");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&Union::Quick::PositionerSource::staticMetaObject, "org.kde.union.impl", 254, nullptr, &Union::Quick::PositionerSource::staticMetaObject, nullptr);
    qmlRegisterEnum<Union::Quick::PositionerSource::Source>("Union::Quick::PositionerSource::Source");
    qmlRegisterTypesAndRevisions<Union::Quick::QuickElement>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::QuickStyle>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::ShadowPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::SizePropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::Sizes>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::StatesGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::StyleHints>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::StylePropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::StyledRectangle>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::TextPropertyGroup>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<Union::Quick::WindowHandler>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<UnionWheelEvent>("org.kde.union.impl", 254);
    qmlRegisterTypesAndRevisions<WheelHandler>("org.kde.union.impl", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.union.impl", 254, 254);
}

static const QQmlModuleRegistration orgkdeunionimplRegistration("org.kde.union.impl", qml_register_types_org_kde_union_impl);
