/****************************************************************************
** Meta object code from reading C++ file 'Element.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../union-6.7.3/src/Element.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Element.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Union7ElementE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Element::qt_create_metaobjectdata<qt_meta_tag_ZN5Union7ElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Element",
        "typeChanged",
        "",
        "idChanged",
        "statesChanged",
        "colorSetChanged",
        "hintsChanged",
        "attributesChanged",
        "updated",
        "type",
        "id",
        "states",
        "States",
        "colorSet",
        "ColorSet",
        "hints",
        "attributes",
        "QVariantMap",
        "State",
        "None",
        "Hovered",
        "ActiveFocus",
        "VisualFocus",
        "Pressed",
        "Checked",
        "Disabled",
        "Highlighted",
        "View",
        "Window",
        "Button",
        "Selection",
        "Tooltip",
        "Complementary",
        "Header",
        "Changes",
        "Change",
        "Nothing",
        "Type",
        "Id",
        "Hints",
        "Attributes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorSetChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attributesChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'states'
        QtMocHelpers::PropertyData<States>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'colorSet'
        QtMocHelpers::PropertyData<enum ColorSet>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'hints'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'attributes'
        QtMocHelpers::PropertyData<QVariantMap>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'States'
        QtMocHelpers::EnumData<States>(12, 18, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   19, State::None },
            {   20, State::Hovered },
            {   21, State::ActiveFocus },
            {   22, State::VisualFocus },
            {   23, State::Pressed },
            {   24, State::Checked },
            {   25, State::Disabled },
            {   26, State::Highlighted },
        }),
        // enum 'ColorSet'
        QtMocHelpers::EnumData<enum ColorSet>(14, 14, QMC::EnumIsScoped).add({
            {   19, ColorSet::None },
            {   27, ColorSet::View },
            {   28, ColorSet::Window },
            {   29, ColorSet::Button },
            {   30, ColorSet::Selection },
            {   31, ColorSet::Tooltip },
            {   32, ColorSet::Complementary },
            {   33, ColorSet::Header },
        }),
        // flag 'Changes'
        QtMocHelpers::EnumData<Changes>(34, 35, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   36, Change::Nothing },
            {   37, Change::Type },
            {   38, Change::Id },
            {   12, Change::States },
            {   39, Change::Hints },
            {   40, Change::Attributes },
        }),
    };
    return QtMocHelpers::metaObjectData<Element, qt_meta_tag_ZN5Union7ElementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Union::Element::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union7ElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union7ElementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union7ElementE_t>.metaTypes,
    nullptr
} };

void Union::Element::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Element *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged(); break;
        case 1: _t->idChanged(); break;
        case 2: _t->statesChanged(); break;
        case 3: _t->colorSetChanged(); break;
        case 4: _t->hintsChanged(); break;
        case 5: _t->attributesChanged(); break;
        case 6: _t->updated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::idChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::statesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::colorSetChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::hintsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::attributesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)()>(_a, &Element::updated, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 2: QtMocHelpers::assignFlags<States>(_v, _t->states()); break;
        case 3: *reinterpret_cast<enum ColorSet*>(_v) = _t->colorSet(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->hints(); break;
        case 5: *reinterpret_cast<QVariantMap*>(_v) = _t->attributes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setStates(*reinterpret_cast<States*>(_v)); break;
        case 3: _t->setColorSet(*reinterpret_cast<enum ColorSet*>(_v)); break;
        case 4: _t->setHints(*reinterpret_cast<QStringList*>(_v)); break;
        case 5: _t->setAttributes(*reinterpret_cast<QVariantMap*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Element::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Element::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union7ElementE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "std::enable_shared_from_this<Element>"))
        return static_cast< std::enable_shared_from_this<Element>*>(this);
    return QObject::qt_metacast(_clname);
}

int Union::Element::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Union::Element::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Union::Element::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Union::Element::statesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Union::Element::colorSetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Union::Element::hintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Union::Element::attributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Union::Element::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
