/****************************************************************************
** Meta object code from reading C++ file 'QuickElement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../union-6.7.3/src/output/qtquick/plugin/QuickElement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QuickElement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Union5Quick11StatesGroupE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::StatesGroup::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick11StatesGroupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::StatesGroup",
        "QML.Element",
        "States",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Grouped property",
        "hoveredChanged",
        "",
        "activeFocusChanged",
        "visualFocusChanged",
        "pressedChanged",
        "checkedChanged",
        "enabledChanged",
        "highlightedChanged",
        "activeStatesChanged",
        "hovered",
        "activeFocus",
        "visualFocus",
        "pressed",
        "checked",
        "enabled",
        "highlighted",
        "activeStates",
        "Union::Element::States"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hoveredChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeFocusChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visualFocusChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkedChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highlightedChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeStatesChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hovered'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'activeFocus'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'visualFocus'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'checked'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'highlighted'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'activeStates'
        QtMocHelpers::PropertyData<Union::Element::States>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<StatesGroup, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN5Union5Quick11StatesGroupE[] = {
    QMetaObject::SuperData::link<Union::Element::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Union::Quick::StatesGroup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick11StatesGroupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick11StatesGroupE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN5Union5Quick11StatesGroupE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick11StatesGroupE_t>.metaTypes,
    nullptr
} };

void Union::Quick::StatesGroup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StatesGroup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hoveredChanged(); break;
        case 1: _t->activeFocusChanged(); break;
        case 2: _t->visualFocusChanged(); break;
        case 3: _t->pressedChanged(); break;
        case 4: _t->checkedChanged(); break;
        case 5: _t->enabledChanged(); break;
        case 6: _t->highlightedChanged(); break;
        case 7: _t->activeStatesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::hoveredChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::activeFocusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::visualFocusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::pressedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::checkedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::highlightedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatesGroup::*)()>(_a, &StatesGroup::activeStatesChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hovered(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->activeFocus(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->visualFocus(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->pressed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->checked(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->highlighted(); break;
        case 7: *reinterpret_cast<Union::Element::States*>(_v) = _t->activeStates(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHovered(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setActiveFocus(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setVisualFocus(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setPressed(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setChecked(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setHighlighted(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Quick::StatesGroup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::StatesGroup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick11StatesGroupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Union::Quick::StatesGroup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Union::Quick::StatesGroup::hoveredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Union::Quick::StatesGroup::activeFocusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Union::Quick::StatesGroup::visualFocusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Union::Quick::StatesGroup::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Union::Quick::StatesGroup::checkedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Union::Quick::StatesGroup::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Union::Quick::StatesGroup::highlightedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Union::Quick::StatesGroup::activeStatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN5Union5Quick11ElementHintE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::ElementHint::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick11ElementHintE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::ElementHint",
        "QML.Element",
        "auto",
        "nameChanged",
        "",
        "whenChanged",
        "name",
        "when"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whenChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'when'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ElementHint, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Union::Quick::ElementHint::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick11ElementHintE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick11ElementHintE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick11ElementHintE_t>.metaTypes,
    nullptr
} };

void Union::Quick::ElementHint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElementHint *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->whenChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ElementHint::*)()>(_a, &ElementHint::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElementHint::*)()>(_a, &ElementHint::whenChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->when(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setWhen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Quick::ElementHint::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::ElementHint::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick11ElementHintE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Union::Quick::ElementHint::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Union::Quick::ElementHint::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Union::Quick::ElementHint::whenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN5Union5Quick16ElementAttributeE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::ElementAttribute::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick16ElementAttributeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::ElementAttribute",
        "QML.Element",
        "auto",
        "valueChanged",
        "",
        "value",
        "QVariant"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ElementAttribute, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Union::Quick::ElementAttribute::staticMetaObject = { {
    QMetaObject::SuperData::link<ElementHint::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick16ElementAttributeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick16ElementAttributeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick16ElementAttributeE_t>.metaTypes,
    nullptr
} };

void Union::Quick::ElementAttribute::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElementAttribute *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->valueChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ElementAttribute::*)()>(_a, &ElementAttribute::valueChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetValue(); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Quick::ElementAttribute::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::ElementAttribute::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick16ElementAttributeE_t>.strings))
        return static_cast<void*>(this);
    return ElementHint::qt_metacast(_clname);
}

int Union::Quick::ElementAttribute::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ElementHint::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Union::Quick::ElementAttribute::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN5Union5Quick12QuickElementE_t {};
} // unnamed namespace

template <> constexpr inline auto Union::Quick::QuickElement::qt_create_metaobjectdata<qt_meta_tag_ZN5Union5Quick12QuickElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Union::Quick::QuickElement",
        "QML.Element",
        "Element",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Attached property",
        "QML.Attached",
        "typeChanged",
        "",
        "elementIdChanged",
        "hintsChanged",
        "attributesChanged",
        "updated",
        "hint",
        "name",
        "parentElement",
        "QuickElement*",
        "type",
        "elementId",
        "states",
        "Union::Quick::StatesGroup*",
        "hints",
        "QQmlListProperty<ElementHint>",
        "attributes",
        "QQmlListProperty<ElementAttribute>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(8, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'elementIdChanged'
        QtMocHelpers::SignalData<void()>(10, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintsChanged'
        QtMocHelpers::SignalData<void()>(11, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attributesChanged'
        QtMocHelpers::SignalData<void()>(12, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(13, 9, QMC::AccessPublic, QMetaType::Void),
        // Method 'hint'
        QtMocHelpers::MethodData<QObject *(const QString &) const>(14, 9, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::QString, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'parentElement'
        QtMocHelpers::PropertyData<QuickElement*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'elementId'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'states'
        QtMocHelpers::PropertyData<Union::Quick::StatesGroup*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'hints'
        QtMocHelpers::PropertyData<QQmlListProperty<ElementHint>>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'attributes'
        QtMocHelpers::PropertyData<QQmlListProperty<ElementAttribute>>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    0 },
    });
    return QtMocHelpers::metaObjectData<QuickElement, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Union::Quick::QuickElement::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickAttachedPropertyPropagator::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick12QuickElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick12QuickElementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Union5Quick12QuickElementE_t>.metaTypes,
    nullptr
} };

void Union::Quick::QuickElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuickElement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged(); break;
        case 1: _t->elementIdChanged(); break;
        case 2: _t->hintsChanged(); break;
        case 3: _t->attributesChanged(); break;
        case 4: _t->updated(); break;
        case 5: { QObject* _r = _t->hint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QuickElement::*)()>(_a, &QuickElement::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickElement::*)()>(_a, &QuickElement::elementIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickElement::*)()>(_a, &QuickElement::hintsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickElement::*)()>(_a, &QuickElement::attributesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickElement::*)()>(_a, &QuickElement::updated, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QuickElement* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Union::Quick::StatesGroup* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QuickElement**>(_v) = _t->parentElement(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->elementId(); break;
        case 3: *reinterpret_cast<Union::Quick::StatesGroup**>(_v) = _t->states(); break;
        case 4: *reinterpret_cast<QQmlListProperty<ElementHint>*>(_v) = _t->hints(); break;
        case 5: *reinterpret_cast<QQmlListProperty<ElementAttribute>*>(_v) = _t->attributes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setType(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setElementId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Union::Quick::QuickElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Union::Quick::QuickElement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Union5Quick12QuickElementE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QQuickAttachedPropertyPropagator::qt_metacast(_clname);
}

int Union::Quick::QuickElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickAttachedPropertyPropagator::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Union::Quick::QuickElement::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Union::Quick::QuickElement::elementIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Union::Quick::QuickElement::hintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Union::Quick::QuickElement::attributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Union::Quick::QuickElement::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
